import { ShaderStageEnum } from '../types/CommonEnum';
import { NodeData, SocketData } from '../types/CommonType';
import { ISocket } from '../sockets/interface/ISocket';
import { INode, NodeClassName } from './INode';
/**
 * A node is an object that has sockets for input and output.
 */
export default abstract class AbstractNode implements INode {
    private static __nodes;
    private __shaderStage;
    private __id;
    private __sockets;
    protected static __existVertexShaderOutputSocket: boolean;
    protected static __existFragmentShaderOutputSocket: boolean;
    /**
     * Create a new node
     * @param nodeData contains data of shader stage
     */
    constructor(nodeData: NodeData, socketDataArray: SocketData[]);
    /**
     * Get all created nodes
     */
    static get allNodes(): AbstractNode[];
    /**
     * Get all created vertex nodes
     */
    static get vertexNodes(): AbstractNode[];
    /**
     * Get all created fragment nodes
     */
    static get fragmentNodes(): AbstractNode[];
    /**
     * Remove all created nodes
     */
    static resetNodes(): void;
    /**
     * Get the node with the specified id
     */
    static getNodeById(id: number): AbstractNode;
    /**
     * Connects two nodes via a specified socket.
     * @param inputNode previous node
     * @param outputSocketNameOfInputNode the socket name to be connected on the previous node
     * @param outputNode post node
     * @param inputSocketNameOfOutputNode the socket name to be connected on the post node
     */
    static connectNodes(inputNode: AbstractNode, outputSocketNameOfInputNode: string, outputNode: AbstractNode, inputSocketNameOfOutputNode: string): void;
    /**
     * Get the shaderStage
     */
    get shaderStage(): ShaderStageEnum;
    /**
     * Get the id of this node
     */
    get id(): number;
    /**
     * @private
     * Get all the sockets of this node
     */
    get _sockets(): ISocket[];
    /**
     * Get connected previous node by input socket name
     * */
    getInputNode(socketName: string): INode | undefined;
    /**
     * Get connected following node by output socket name
     * */
    getOutputNodes(socketName: string): INode[];
    /**
     * Get variable name corresponding specified socket
     * Return '' if the socket is not found or is StandardInputSocket
     * */
    getVariableNameOfInputSocket(socketName: string): string;
    /**
     * @private
     * Get input socket by socket name
     * */
    private __getInputSocket;
    /**
     * @private
     * Get output socket by socket name
     * */
    private __getOutputSocket;
    /**
     * @private
     * Add socket to this node
     */
    protected __addSocket(socket: ISocket): void;
    /**
     * @private
     * Get the class name of this instance
     */
    abstract get className(): NodeClassName;
    /**
     * @private
     * attach sockets to this node
     */
    protected abstract __addSockets(socketDataArray: SocketData[]): void;
}
