import { ShaderityNodeData, SocketData } from '../types/CommonType';
import AbstractNode from './AbstractNode';
/**
 * A shaderity node is an node that contains functions to be used in the shader.
 * Each sockets corresponds to a shader function argument of a node.
 *
 * The node graph which is the collection of connected nodes is transformed into a shader by
 * calling the shader functions of nodes sequentially. Nodes are connected to each other via sockets,
 * and data can be passed between them.
 *
 * Note1: Data of attribute/varying/uniform variable must be passed to a node through
 *        AttributeInputSocket/VaryingInputSocket/UniformInputSocket.
 *        Do not write these variables directly into the function of each node.
 *        They must be specified in the function arguments.
 *
 * Note2: This node cannot attach sampler type output socket.
 *        To use the socket, you need to use sampler node instead of this node
 */
export default class ShaderityNode extends AbstractNode {
    private __shaderFunctionName;
    private __shaderFunctionDataKey;
    /**
     * Create a new node
     * @param nodeData define shader function name and shader stage
     * @param socketDataArray define sockets. The order of the socketData must match the order of
     *                        the arguments of the node's shader function.
     */
    constructor(nodeData: ShaderityNodeData, socketDataArray: SocketData[]);
    static get allShaderityNodes(): ShaderityNode[];
    static get vertexShaderityNodes(): ShaderityNode[];
    static get fragmentShaderityNodes(): ShaderityNode[];
    /**
     * Get the name of the function that corresponds to entry point of this node in the shader
     */
    get className(): 'ShaderityNode';
    /**
     * Set the name of the function that corresponds to the entry point of this node in the shader
     */
    set functionName(name: string);
    /**
     * Get the name of the function that corresponds to entry point of this node in the shader
     */
    get functionName(): string;
    /**
     * Get the corresponding function of this node from ShaderFunctionDataRepository
     */
    get shaderCode(): string;
    /**
     * @private
     * Get shaderFunctionDataKey
     */
    get _shaderFunctionDataKey(): string;
    /**
     * @private
     * Get the webgl extension used by the functions of this node
     */
    get _extensions(): string[];
    /**
     * @protected
     * attach sockets to this node
     */
    protected __addSockets(socketDataArray: SocketData[]): void;
    /**
     * @private
     * Add input socket of this node to connect another node
     */
    private __addInputSocket;
    /**
     * @private
     * Check for duplicate socket names in the input sockets.
     */
    private __checkDuplicationOfInputSocket;
    /**
     * @private
     * Add output socket of this node to connect another node
     */
    private __addOutputSocket;
    /**
     * @private
     * Check for duplicate socket names in the output sockets.
     */
    private __checkDuplicationOfOutputSocket;
    /**
     * @private
     * Display an error message if there are two or more ShaderOutputSockets in the same shader stage.
     */
    private __checkUniquenessOfShaderOutputSocket;
}
